@@ -14,70 +14,23 @@ from os import listdir
 from os.path import exists, expanduser, isfile, join
 import re
 import sys
+from textwrap import dedent
 
-from .common import add_parser_json, add_parser_offline, arg2spec, handle_envs_list, stdout_json
-from ..common.compat import iteritems, itervalues, on_win
+from .common import print_envs_list, stdout_json
+from .. import CONDA_PACKAGE_ROOT, __version__ as conda_version
+from ..base.context import conda_in_private_env, context, sys_rc_path, user_rc_path
+from ..common.compat import iteritems, itervalues, on_win, text_type
+from ..common.url import mask_anaconda_token
+from ..core.envs_manager import env_name
+from ..core.subdir_data import SubdirData
+from ..models.channel import all_channel_urls, offline_keep
+from ..models.match_spec import MatchSpec
+from ..utils import human_bytes
 
 log = getLogger(__name__)
 
-help = "Display information about current conda install."
 
-example = """
-
-Examples:
-
-    conda info -a
-"""
-
-def configure_parser(sub_parsers):
-    p = sub_parsers.add_parser(
-        'info',
-        description=help,
-        help=help,
-        epilog=example,
-    )
-    add_parser_json(p)
-    add_parser_offline(p)
-    p.add_argument(
-        '-a', "--all",
-        action="store_true",
-        help="Show all information, (environments, license, and system "
-             "information.")
-    p.add_argument(
-        '-e', "--envs",
-        action="store_true",
-        help="List all known conda environments.",
-    )
-    p.add_argument(
-        '-l', "--license",
-        action="store_true",
-        help="Display information about the local conda licenses list.",
-    )
-    p.add_argument(
-        '-s', "--system",
-        action="store_true",
-        help="List environment variables.",
-    )
-    p.add_argument(
-        'packages',
-        action="store",
-        nargs='*',
-        help="Display information about packages.",
-    )
-    p.add_argument(
-        '--root',
-        action='store_true',
-        help='Display root environment path.',
-    )
-    p.add_argument(
-        '--unsafe-channels',
-        action='store_true',
-        help='Display list of channels with tokens exposed.',
-    )
-    p.set_defaults(func=execute)
-
-
-def get_user_site():
+def get_user_site():  # pragma: no cover
     site_dirs = []
     try:
         if not on_win:
@@ -98,8 +51,7 @@ def get_user_site():
     return site_dirs
 
 
-IGNORE_FIELDS = {'files', 'auth', 'with_features_depends',
-                 'preferred_env', 'priority'}
+IGNORE_FIELDS = {'files', 'auth', 'preferred_env', 'priority'}
 
 SKIP_FIELDS = IGNORE_FIELDS | {'name', 'version', 'build', 'build_number',
                                'channel', 'schannel', 'size', 'fn', 'depends'}
@@ -109,17 +61,16 @@ def dump_record(pkg):
     return {k: v for k, v in iteritems(pkg.dump()) if k not in IGNORE_FIELDS}
 
 
-def pretty_package(dist, pkg):
-    from ..utils import human_bytes
+def pretty_package(prec):
 
-    pkg = dump_record(pkg)
+    pkg = dump_record(prec)
     d = OrderedDict([
-        ('file name', dist.to_filename()),
+        ('file name', prec.fn),
         ('name', pkg['name']),
         ('version', pkg['version']),
         ('build string', pkg['build']),
         ('build number', pkg['build_number']),
-        ('channel', dist.channel),
+        ('channel', text_type(prec.channel)),
         ('size', human_bytes(pkg['size'])),
     ])
     for key in sorted(set(pkg.keys()) - SKIP_FIELDS):
@@ -137,36 +88,26 @@ def pretty_package(dist, pkg):
 
 
 def print_package_info(packages):
-    from ..api import get_index
-    from ..base.context import context
-    from ..resolve import Resolve
-    index = get_index()
-    r = Resolve(index)
+
+    results = {}
+    for package in packages:
+        spec = MatchSpec(package)
+        results[package] = tuple(SubdirData.query_all(spec))
+
     if context.json:
-        stdout_json({
-            package: [dump_record(r.index[d])
-                      for d in r.get_dists_for_spec(arg2spec(package))]
-            for package in packages
-        })
+        stdout_json({package: results[package] for package in packages})
     else:
-        for package in packages:
-            for dist in r.get_dists_for_spec(arg2spec(package)):
-                pretty_package(dist, r.index[dist])
+        for result in itervalues(results):
+            for prec in result:
+                pretty_package(prec)
 
 
 def get_info_dict(system=False):
-    from .. import CONDA_PACKAGE_ROOT, __version__ as conda_version
-    from ..base.context import context
-    from ..common.url import mask_anaconda_token
-    from ..config import rc_path, sys_rc_path, user_rc_path
-    from ..connection import user_agent
-    from ..models.channel import offline_keep, prioritize_channels
-
     try:
         from ..install import linked_data
         root_pkgs = linked_data(context.root_prefix)
-    except:
-        root_pkgs = None
+    except:  # pragma: no cover
+        root_pkgs = {}
 
     try:
         from requests import __version__ as requests_version
@@ -175,14 +116,17 @@ def get_info_dict(system=False):
         #   REQUESTS_CA_BUNDLE
         #   HTTP_PROXY
         #   HTTPS_PROXY
-    except ImportError:
-        requests_version = "could not import"
-    except Exception as e:
+    except ImportError:  # pragma: no cover
+        try:
+            from pip._vendor.requests import __version__ as requests_version
+        except Exception as e:  # pragma: no cover
+            requests_version = "Error %r" % e
+    except Exception as e:  # pragma: no cover
         requests_version = "Error %r" % e
 
     try:
         from conda_env import __version__ as conda_env_version
-    except:
+    except:  # pragma: no cover
         try:
             cenv = [p for p in itervalues(root_pkgs) if p['name'] == 'conda-env']
             conda_env_version = cenv[0]['version']
@@ -191,25 +135,30 @@ def get_info_dict(system=False):
 
     try:
         import conda_build
-    except ImportError:
+    except ImportError:  # pragma: no cover
         conda_build_version = "not installed"
-    except Exception as e:
+    except Exception as e:  # pragma: no cover
         conda_build_version = "Error %s" % e
-    else:
+    else:  # pragma: no cover
         conda_build_version = conda_build.__version__
 
-    channels = list(prioritize_channels(context.channels).keys())
+    channels = list(all_channel_urls(context.channels))
     if not context.json:
         channels = [c + ('' if offline_keep(c) else '  (offline)')
                     for c in channels]
     channels = [mask_anaconda_token(c) for c in channels]
 
+    config_files = tuple(path for path in context.collect_all()
+                         if path not in ('envvars', 'cmd_line'))
+
     netrc_file = os.environ.get('NETRC')
     if not netrc_file:
         user_netrc = expanduser("~/.netrc")
         if isfile(user_netrc):
             netrc_file = user_netrc
 
+    active_prefix_name = env_name(context.active_prefix)
+
     info_dict = dict(
         platform=context.subdir,
         conda_version=conda_version,
@@ -217,22 +166,26 @@ def get_info_dict(system=False):
         conda_build_version=conda_build_version,
         root_prefix=context.root_prefix,
         conda_prefix=context.conda_prefix,
-        conda_private=context.conda_private,
+        conda_private=conda_in_private_env(),
         root_writable=context.root_writable,
         pkgs_dirs=context.pkgs_dirs,
         envs_dirs=context.envs_dirs,
         default_prefix=context.default_prefix,
+        active_prefix=context.active_prefix,
+        active_prefix_name=active_prefix_name,
+        conda_shlvl=context.shlvl,
         channels=channels,
-        rc_path=rc_path,
         user_rc_path=user_rc_path,
+        rc_path=user_rc_path,
         sys_rc_path=sys_rc_path,
         # is_foreign=bool(foreign),
         offline=context.offline,
         envs=[],
         python_version='.'.join(map(str, sys.version_info)),
         requests_version=requests_version,
-        user_agent=user_agent,
+        user_agent=context.user_agent,
         conda_location=CONDA_PACKAGE_ROOT,
+        config_files=config_files,
         netrc_file=netrc_file,
     )
     if on_win:
@@ -242,78 +195,98 @@ def get_info_dict(system=False):
         info_dict['UID'] = os.geteuid()
         info_dict['GID'] = os.getegid()
 
-    if system:
-        evars = {
-            'CIO_TEST',
-            'CONDA_DEFAULT_ENV',
-            'CONDA_ENVS_PATH',
-            'DYLD_LIBRARY_PATH',
-            'FTP_PROXY',
-            'HTTP_PROXY',
-            'HTTPS_PROXY',
-            'LD_LIBRARY_PATH',
-            'PATH',
-            'PYTHONHOME',
-            'PYTHONPATH',
-            'REQUESTS_CA_BUNDLE',
-            'SSL_CERT_FILE',
-        }
+    env_var_keys = {
+        'CIO_TEST',
+        'REQUESTS_CA_BUNDLE',
+        'SSL_CERT_FILE',
+    }
 
-        evars.update(v for v in os.environ if v.startswith('CONDA_'))
-        evars.update(v for v in os.environ if v.startswith('conda_'))
+    # add all relevant env vars, e.g. startswith('CONDA') or endswith('PATH')
+    env_var_keys.update(v for v in os.environ if v.upper().startswith('CONDA'))
+    env_var_keys.update(v for v in os.environ if v.upper().startswith('PYTHON'))
+    env_var_keys.update(v for v in os.environ if v.upper().endswith('PATH'))
+    env_var_keys.update(v for v in os.environ if v.upper().startswith('SUDO'))
 
-        info_dict.update({
-            'sys.version': sys.version,
-            'sys.prefix': sys.prefix,
-            'sys.executable': sys.executable,
-            'site_dirs': get_user_site(),
-            'env_vars': {ev: os.getenv(ev, os.getenv(ev.lower(), '<not set>')) for ev in evars},
-        })
+    env_vars = {ev: os.getenv(ev, os.getenv(ev.lower(), '<not set>')) for ev in env_var_keys}
+
+    proxy_keys = (v for v in os.environ if v.upper().endswith('PROXY'))
+    env_vars.update({ev: '<set>' for ev in proxy_keys})
+
+    info_dict.update({
+        'sys.version': sys.version,
+        'sys.prefix': sys.prefix,
+        'sys.executable': sys.executable,
+        'site_dirs': get_user_site(),
+        'env_vars': env_vars,
+    })
 
     return info_dict
 
 
-def get_main_info_str(info_dict):
-    from .._vendor.auxlib.ish import dals
+def get_env_vars_str(info_dict):
+    from textwrap import wrap
+    builder = []
+    builder.append("%23s:" % "environment variables")
+    env_vars = info_dict.get('env_vars', {})
+    for key in sorted(env_vars):
+        value = wrap(env_vars[key])
+        first_line = value[0] if len(value) else ""
+        other_lines = value[1:] if len(value) > 1 else ()
+        builder.append("%25s=%s" % (key, first_line))
+        for val in other_lines:
+            builder.append(' ' * 26 + val)
+    return '\n'.join(builder)
 
-    for key in 'pkgs_dirs', 'envs_dirs', 'channels':
+
+def get_main_info_str(info_dict):
+    for key in 'pkgs_dirs', 'envs_dirs', 'channels', 'config_files':
         info_dict['_' + key] = ('\n' + 26 * ' ').join(info_dict[key])
     info_dict['_rtwro'] = ('writable' if info_dict['root_writable'] else 'read only')
 
-    builder = []
-    builder.append(dals("""
-    Current conda install:
+    format_param = lambda nm, val: "%23s : %s" % (nm, val)
 
-                   platform : %(platform)s
-              conda version : %(conda_version)s
-           conda is private : %(conda_private)s
-          conda-env version : %(conda_env_version)s
-        conda-build version : %(conda_build_version)s
-             python version : %(python_version)s
-           requests version : %(requests_version)s
-           root environment : %(root_prefix)s  (%(_rtwro)s)
-        default environment : %(default_prefix)s
-           envs directories : %(_envs_dirs)s
-              package cache : %(_pkgs_dirs)s
-               channel URLs : %(_channels)s
-                config file : %(rc_path)s
-                 netrc file : %(netrc_file)s
-               offline mode : %(offline)s
-                 user-agent : %(user_agent)s\
-    """) % info_dict)
+    builder = ['']
+
+    if info_dict['active_prefix_name']:
+        builder.append(format_param('active environment', info_dict['active_prefix_name']))
+        builder.append(format_param('active env location', info_dict['active_prefix']))
+    else:
+        builder.append(format_param('active environment', info_dict['active_prefix']))
+
+    if info_dict['conda_shlvl'] >= 0:
+        builder.append(format_param('shell level', info_dict['conda_shlvl']))
+
+    builder.extend((
+        format_param('user config file', info_dict['user_rc_path']),
+        format_param('populated config files', info_dict['_config_files']),
+        format_param('conda version', info_dict['conda_version']),
+        format_param('conda-build version', info_dict['conda_build_version']),
+        format_param('python version', info_dict['python_version']),
+        format_param('base environment', '%s  (%s)' % (info_dict['root_prefix'],
+                                                       info_dict['_rtwro'])),
+        format_param('channel URLs', info_dict['_channels']),
+        format_param('package cache', info_dict['_pkgs_dirs']),
+        format_param('envs directories', info_dict['_envs_dirs']),
+        format_param('platform', info_dict['platform']),
+        format_param('user-agent', info_dict['user_agent']),
+    ))
 
     if on_win:
-        builder.append("          administrator : %(is_windows_admin)s" % info_dict)
+        builder.append(format_param("administrator", info_dict['is_windows_admin']))
     else:
-        builder.append("                UID:GID : %(UID)s:%(GID)s" % info_dict)
+        builder.append(format_param("UID:GID", '%s:%s' % (info_dict['UID'], info_dict['GID'])))
 
+    builder.extend((
+        format_param('netrc file', info_dict['netrc_file']),
+        format_param('offline mode', info_dict['offline']),
+    ))
+
+    builder.append('')
     return '\n'.join(builder)
 
 
 def execute(args, parser):
-    from ..base.context import context
-
-    if args.root:
+    if args.base:
         if context.json:
             stdout_json({'root_prefix': context.root_prefix})
         else:
@@ -321,8 +294,13 @@ def execute(args, parser):
         return
 
     if args.packages:
-        print_package_info(args.packages)
-        return
+        from ..resolve import ResolvePackageNotFound
+        try:
+            print_package_info(args.packages)
+            return
+        except ResolvePackageNotFound as e:  # pragma: no cover
+            from ..exceptions import PackagesNotFoundError
+            raise PackagesNotFoundError(e.bad_deps)
 
     if args.unsafe_channels:
         if not context.json:
@@ -336,14 +314,15 @@ def execute(args, parser):
     if args.all or context.json:
         for option in options:
             setattr(args, option, True)
-
     info_dict = get_info_dict(args.system)
 
     if (args.all or all(not getattr(args, opt) for opt in options)) and not context.json:
         print(get_main_info_str(info_dict))
 
     if args.envs:
-        handle_envs_list(info_dict['envs'], not context.json)
+        from ..core.envs_manager import list_all_known_prefixes
+        info_dict['envs'] = list_all_known_prefixes()
+        print_envs_list(info_dict['envs'], not context.json)
 
     if args.system:
         if not context.json:
@@ -352,10 +331,10 @@ def execute(args, parser):
             print("sys.prefix: %s" % sys.prefix)
             print("sys.executable: %s" % sys.executable)
             print("conda location: %s" % info_dict['conda_location'])
-            for cmd in sorted(set(find_commands() + ['build'])):
+            for cmd in sorted(set(find_commands() + ('build',))):
                 print("conda-%s: %s" % (cmd, find_executable('conda-' + cmd)))
             print("user site dirs: ", end='')
-            site_dirs = get_user_site()
+            site_dirs = info_dict['site_dirs']
             if site_dirs:
                 print(site_dirs[0])
             else:
@@ -371,12 +350,14 @@ def execute(args, parser):
     if args.license and not context.json:
         try:
             from _license import show_info
-            show_info()
+            show_info()  # pragma: no cover
         except ImportError:
-            print("""\
-WARNING: could not import _license.show_info
-# try:
-# $ conda install -n root _license""")
+            print(dedent("""
+                WARNING: could not import _license.show_info
+                # try:
+                # $ conda install -n root _license"""))
+        except Exception as e:  # pragma: no cover
+            log.warn('%r', e)
 
     if context.json:
         stdout_json(info_dict)
