@@ -46,6 +46,7 @@ elif PY2:  # pragma: py3 no cover
 # #############################
 
 if PY3:  # pragma: py2 no cover
+    from collections.abc import Mapping, Sequence
     from io import StringIO
     from itertools import zip_longest
     if sys.version_info[1] >= 5:
@@ -54,6 +55,7 @@ if PY3:  # pragma: py2 no cover
     else:
         JSONDecodeError = ValueError
 elif PY2:  # pragma: py3 no cover
+    from collections import Mapping, Sequence
     from cStringIO import StringIO
     from itertools import izip as zip, izip_longest as zip_longest
     JSONDecodeError = ValueError
