@@ -90,8 +90,7 @@ def tokenized_startswith(test_iterable, startswith_iterable):
 
 
 def get_all_directories(files):
-    directories = sorted(set(tuple(f.split('/')[:-1]) for f in files))
-    return directories or ()
+    return sorted(set(tuple(f.split('/')[:-1]) for f in files) - {()})
 
 
 def get_leaf_directories(files):
@@ -122,7 +121,8 @@ def explode_directories(child_directories, already_split=False):
     # get all directories including parents
     # use already_split=True for the result of get_all_directories()
     maybe_split = lambda x: x if already_split else x.split('/')
-    return set(concat(accumulate(join, maybe_split(directory)) for directory in child_directories))
+    return set(concat(accumulate(join, maybe_split(directory))
+                      for directory in child_directories if directory))
 
 
 def pyc_path(py_path, python_major_minor_version):
